==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/ResourceAccessReviewBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ResourceAccessReviewBuilder extends io.fabric8.openshift.api.model.ResourceAccessReviewFluentImpl<io.fabric8.openshift.api.model.ResourceAccessReviewBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ResourceAccessReview,io.fabric8.openshift.api.model.ResourceAccessReviewBuilder>{
  public ResourceAccessReviewBuilder() {
    this(false);
  }
  public ResourceAccessReviewBuilder(java.lang.Boolean validationEnabled) {
    this(new ResourceAccessReview(), validationEnabled);
  }
  public ResourceAccessReviewBuilder(io.fabric8.openshift.api.model.ResourceAccessReviewFluent<?> fluent) {
    this(fluent, false);
  }
  public ResourceAccessReviewBuilder(io.fabric8.openshift.api.model.ResourceAccessReviewFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ResourceAccessReview(), validationEnabled);
  }
  public ResourceAccessReviewBuilder(io.fabric8.openshift.api.model.ResourceAccessReviewFluent<?> fluent,io.fabric8.openshift.api.model.ResourceAccessReview instance) {
    this(fluent, instance, false);
  }
  public ResourceAccessReviewBuilder(io.fabric8.openshift.api.model.ResourceAccessReviewFluent<?> fluent,io.fabric8.openshift.api.model.ResourceAccessReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withContent(instance.getContent()); 
    fluent.withIsNonResourceURL(instance.getIsNonResourceURL()); 
    fluent.withKind(instance.getKind()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withPath(instance.getPath()); 
    fluent.withResource(instance.getResource()); 
    fluent.withResourceAPIGroup(instance.getResourceAPIGroup()); 
    fluent.withResourceAPIVersion(instance.getResourceAPIVersion()); 
    fluent.withResourceName(instance.getResourceName()); 
    fluent.withVerb(instance.getVerb()); 
    this.validationEnabled = validationEnabled; 
  }
  public ResourceAccessReviewBuilder(io.fabric8.openshift.api.model.ResourceAccessReview instance) {
    this(instance,false);
  }
  public ResourceAccessReviewBuilder(io.fabric8.openshift.api.model.ResourceAccessReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withContent(instance.getContent()); 
    this.withIsNonResourceURL(instance.getIsNonResourceURL()); 
    this.withKind(instance.getKind()); 
    this.withNamespace(instance.getNamespace()); 
    this.withPath(instance.getPath()); 
    this.withResource(instance.getResource()); 
    this.withResourceAPIGroup(instance.getResourceAPIGroup()); 
    this.withResourceAPIVersion(instance.getResourceAPIVersion()); 
    this.withResourceName(instance.getResourceName()); 
    this.withVerb(instance.getVerb()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ResourceAccessReviewFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ResourceAccessReview build() {
    ResourceAccessReview buildable = new ResourceAccessReview(fluent.getApiVersion(),fluent.getContent(),fluent.getIsNonResourceURL(),fluent.getKind(),fluent.getNamespace(),fluent.getPath(),fluent.getResource(),fluent.getResourceAPIGroup(),fluent.getResourceAPIVersion(),fluent.getResourceName(),fluent.getVerb());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ResourceAccessReviewBuilder that = (ResourceAccessReviewBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ResourceAccessReviewBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ResourceAccessReviewBuilder extends io.fabric8.openshift.api.model.ResourceAccessReviewFluentImpl<io.fabric8.openshift.api.model.ResourceAccessReviewBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ResourceAccessReview,io.fabric8.openshift.api.model.ResourceAccessReviewBuilder>{
  public ResourceAccessReviewBuilder() {
    this(false);
  }
  public ResourceAccessReviewBuilder(java.lang.Boolean validationEnabled) {
    this(new ResourceAccessReview(), validationEnabled);
  }
  public ResourceAccessReviewBuilder(io.fabric8.openshift.api.model.ResourceAccessReviewFluent<?> fluent) {
    this(fluent, false);
  }
  public ResourceAccessReviewBuilder(io.fabric8.openshift.api.model.ResourceAccessReviewFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ResourceAccessReview(), validationEnabled);
  }
  public ResourceAccessReviewBuilder(io.fabric8.openshift.api.model.ResourceAccessReviewFluent<?> fluent,io.fabric8.openshift.api.model.ResourceAccessReview instance) {
    this(fluent, instance, false);
  }
  public ResourceAccessReviewBuilder(io.fabric8.openshift.api.model.ResourceAccessReviewFluent<?> fluent,io.fabric8.openshift.api.model.ResourceAccessReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withContent(instance.getContent()); 
    fluent.withIsNonResourceURL(instance.getIsNonResourceURL()); 
    fluent.withKind(instance.getKind()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withPath(instance.getPath()); 
    fluent.withResource(instance.getResource()); 
    fluent.withResourceAPIGroup(instance.getResourceAPIGroup()); 
    fluent.withResourceAPIVersion(instance.getResourceAPIVersion()); 
    fluent.withResourceName(instance.getResourceName()); 
    fluent.withVerb(instance.getVerb()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ResourceAccessReviewBuilder(io.fabric8.openshift.api.model.ResourceAccessReview instance) {
    this(instance,false);
  }
  public ResourceAccessReviewBuilder(io.fabric8.openshift.api.model.ResourceAccessReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withContent(instance.getContent()); 
    this.withIsNonResourceURL(instance.getIsNonResourceURL()); 
    this.withKind(instance.getKind()); 
    this.withNamespace(instance.getNamespace()); 
    this.withPath(instance.getPath()); 
    this.withResource(instance.getResource()); 
    this.withResourceAPIGroup(instance.getResourceAPIGroup()); 
    this.withResourceAPIVersion(instance.getResourceAPIVersion()); 
    this.withResourceName(instance.getResourceName()); 
    this.withVerb(instance.getVerb()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ResourceAccessReviewFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ResourceAccessReview build() {
    ResourceAccessReview buildable = new ResourceAccessReview(fluent.getApiVersion(),fluent.getContent(),fluent.getIsNonResourceURL(),fluent.getKind(),fluent.getNamespace(),fluent.getPath(),fluent.getResource(),fluent.getResourceAPIGroup(),fluent.getResourceAPIVersion(),fluent.getResourceName(),fluent.getVerb());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ResourceAccessReviewBuilder that = (ResourceAccessReviewBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
